==> keyclic_sdk_api-1.39.1.tar.gz: lib/model/category_pagination.dart <==
part of keyclic_sdk_api.api;

class CategoryPagination {
  int limit = null;

  int page = null;

  int pages = null;

  int total = null;

  CategoryCollection embedded = null;

  PaginationLinks links = null;

  CategoryPagination({
    this.limit,
    this.page,
    this.pages,
    this.total,
    this.embedded,
    this.links,
  });

  @override
  String toString() {
    return 'CategoryPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  CategoryPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = new CategoryCollection.fromJson(json['_embedded']);
    links = new PaginationLinks.fromJson(json['_links']);
  }

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      '_embedded': embedded,
      '_links': links,
    };
  }

  static List<CategoryPagination> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<CategoryPagination>()
        : json.map((value) => new CategoryPagination.fromJson(value)).toList();
  }

  static Map<String, CategoryPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, CategoryPagination>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new CategoryPagination.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.39.4.tar.gz: lib/model/category_pagination.dart <==
part of keyclic_sdk_api.api;

class CategoryPagination {
  CategoryPagination({
    this.limit,
    this.page,
    this.pages,
    this.total,
    this.embedded,
    this.links,
  });

  CategoryPagination.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    limit = json['limit'];
    page = json['page'];
    pages = json['pages'];
    total = json['total'];
    embedded = CategoryCollection.fromJson(json['_embedded']);
    links = PaginationLinks.fromJson(json['_links']);
  }

  int limit;

  int page;

  int pages;

  int total;

  CategoryCollection embedded;

  PaginationLinks links;

  Map<String, dynamic> toJson() {
    return {
      'limit': limit,
      'page': page,
      'pages': pages,
      'total': total,
      '_embedded': embedded,
      '_links': links,
    };
  }

  @override
  String toString() {
    return 'CategoryPagination[limit=$limit, page=$page, pages=$pages, total=$total, embedded=$embedded, links=$links, ]';
  }

  static List<CategoryPagination> listFromJson(List<dynamic> json) {
    return json == null
        ? List<CategoryPagination>()
        : json.map((value) => CategoryPagination.fromJson(value)).toList();
  }

  static Map<String, CategoryPagination> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, CategoryPagination>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = CategoryPagination.fromJson(value));
    }
    return map;
  }
}
